@@ -12,6 +12,7 @@ from commitizen.cz.exceptions import CzException
 from commitizen.cz.utils import get_backup_file_path
 from commitizen.exceptions import (
     CommitError,
+    CommitMessageLengthExceededError,
     CustomError,
     DryRunExit,
     NoAnswersError,
@@ -61,7 +62,16 @@ class Commit:
 
         if not answers:
             raise NoAnswersError()
-        return cz.message(answers)
+
+        message = cz.message(answers)
+        message_len = len(message.partition("\n")[0].strip())
+        message_length_limit: int = self.arguments.get("message_length_limit", 0)
+        if 0 < message_length_limit < message_len:
+            raise CommitMessageLengthExceededError(
+                f"Length of commit message exceeds limit ({message_len}/{message_length_limit})"
+            )
+
+        return message
 
     def __call__(self):
         dry_run: bool = self.arguments.get("dry_run")
